==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/popup-trigger.h <==
//$Id: popup-trigger.h,v 1.11 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_H
#define GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_H

namespace Guikachu
{
    namespace Widgets
    {
	class PopupTrigger;
    }
}

#include "widget.h"
#include "widget-ref.h"
#include "resizeable.h"
#include "textual.h"

#include "popup-trigger-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class PopupTrigger: public Widget,
			    public Resizeable,
			    public Textual
	{
	    GUI::FormEditor::PopupTriggerProperties *editor;
	    
	public:
	    PopupTrigger (Resources::Form   *owner,
			  const std::string &id);
	    virtual ~PopupTrigger ();
	    
	    virtual Type get_type () const { return WIDGET_POPUP_TRIGGER; };
	    
	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget                 *create_editor ();
	    
	    Properties::WidgetRef list_id;
	    Property<bool>        usable;
	    Property<bool>        anchor_right;

	protected:
	    virtual int get_auto_width  () const;
	    virtual int get_auto_height () const;

	private:
	    // Persistance
	    virtual bool load (StorageNode      &node);
	    virtual void save (StorageNode      &node) const;
	    virtual void save_rcp (std::ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_H */

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/popup-trigger.h <==
//$Id: popup-trigger.h,v 1.22 2004/01/18 13:05:39 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_H
#define GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_H

#include "widget.h"
#include "widget-ref.h"
#include "auto-resizeable.h"
#include "textual.h"
#include "graphical.h"

namespace Guikachu
{
    namespace Widgets
    {
	class PopupTrigger: public Widget,
			    public AutoWidth,
			    public AutoHeight,
			    public Textual,
                            public Graphical
	{
	public:
	    PopupTrigger (Resources::Form *owner, const std::string &id, serial_t serial);
	    
	    Type get_type () const { return WIDGET_POPUP_TRIGGER; };
	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
	    
	    Properties::WidgetRef list_id;
	    Property<bool>        usable;
	    Property<bool>        anchor_right;

	protected:
	    int get_auto_width  () const;
	    int get_auto_height () const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_POPUP_TRIGGER_H */
